@@ -2,21 +2,24 @@
 /*!	\file synfig/blur.cpp
 **	\brief Blur Implementation File
 **
-**	$Id$
-**
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
 **	Copyright (c) 2012-2013 Carlos López
 **
-**	This package is free software; you can redistribute it and/or
-**	modify it under the terms of the GNU General Public License as
-**	published by the Free Software Foundation; either version 2 of
-**	the License, or (at your option) any later version.
+**	This file is part of Synfig.
 **
-**	This package is distributed in the hope that it will be useful,
+**	Synfig is free software: you can redistribute it and/or modify
+**	it under the terms of the GNU General Public License as published by
+**	the Free Software Foundation, either version 2 of the License, or
+**	(at your option) any later version.
+**
+**	Synfig is distributed in the hope that it will be useful,
 **	but WITHOUT ANY WARRANTY; without even the implied warranty of
-**	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
-**	General Public License for more details.
+**	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+**	GNU General Public License for more details.
+**
+**	You should have received a copy of the GNU General Public License
+**	along with Synfig.  If not, see <https://www.gnu.org/licenses/>.
 **	\endlegal
 */
 /* ========================================================================= */
@@ -30,21 +33,20 @@
 #	include <config.h>
 #endif
 
-#include <stdexcept>
-
-#include <ETL/boxblur>
-#include <ETL/gaussian>
-
 #include "blur.h"
 
-#include "general.h"
+#include <vector>
+
+#include <synfig/blur/boxblur.h>
+#include <synfig/blur/gaussian.h>
+
+#include <synfig/general.h>
 #include <synfig/localization.h>
 
 #endif
 
 /* === U S I N G =========================================================== */
 
-using namespace etl;
 using namespace synfig;
 
 /* === M A C R O S ========================================================= */
@@ -97,7 +99,7 @@ Point Blur::operator()(const Point &pos) const
 
 	case DISC:
 		{
-			Angle theta=Angle::rotations((float)rand()/(float)RAND_MAX);
+			Angle theta=Angle::rot((float)rand()/(float)RAND_MAX);
 			Vector::value_type mag=(float)rand()/(float)RAND_MAX;
 			Vector vect((float)Angle::cos(theta).get()*mag,(float)Angle::sin(theta).get()*mag);
 
@@ -153,25 +155,25 @@ inline Color zero<Color>()
 	return Color::alpha();
 }
 
-template <typename T,typename AT,class VP>
-static void GaussianBlur_2x2(etl::surface<T,AT,VP> &surface)
+template <typename T,class VP>
+static void GaussianBlur_2x2(synfig::surface<T,VP>& surface)
 {
 	int x,y,w,h;
-	AT Tmp1,Tmp2,SR0;
+	T Tmp1,Tmp2,SR0;
 
 	w=surface.get_w();
 	h=surface.get_h();
 	
-	AT *SC0=new AT[w];
+	T *SC0=new T[w];
 
-	memcpy(static_cast<void*>(SC0), surface[0], w*sizeof(AT));
+	memcpy(static_cast<void*>(SC0), surface[0], w*sizeof(T));
 
 	for(y=0;y<h;y++)
 	{
 		SR0=surface[y][0];
 		for(x=0;x<w;x++)
 		{
-			Tmp1=(AT)(surface[y][x]);
+			Tmp1=surface[y][x];
 			Tmp2=SR0+Tmp1;
 			SR0=Tmp1;
 			surface[y][x]=(SC0[x]+Tmp2)/4;
@@ -181,212 +183,11 @@ static void GaussianBlur_2x2(etl::surface<T,AT,VP> &surface)
 	delete [] SC0;
 }
 
-template <typename T,typename AT,class VP>
-static void GaussianBlur_3x3(etl::surface<T,AT,VP> &surface)
-{
-	int x,y,u,v,w,h;
-	AT Tmp1,Tmp2,SR0,SR1;
-
-	w=surface.get_w();
-	h=surface.get_h();
-
-	AT *SC0=new AT[w+1];
-	AT *SC1=new AT[w+1];
-
-	// Setup the row buffers
-	for(x=0;x<w;x++)SC0[x]=(AT)(surface[0][x])*4;
-
-	for(y=0;y<=h;y++)
-	{
-		if(y>=h)
-			v=h-1;
-		else
-			v=y;
-
-		SR0=SR1=surface[y][0];
-		for(x=0;x<=w;x++)
-		{
-			if(x>=w)
-				u=w-1;
-			else
-				u=x;
-
-			// Row Machine
-			Tmp1=surface[v][u];
-			Tmp2=SR0+Tmp1;
-			SR0=Tmp1;
-			Tmp1=SR1+Tmp2;
-			SR1=Tmp2;
-
-			// Column Machine
-			Tmp2=SC0[x]+Tmp1;
-			SC0[x]=Tmp1;
-			if(y&&x)
-				surface[y-1][x-1]=(SC1[x]+Tmp2)/16;
-			SC1[x]=Tmp2;
-		}
-	}
-
-	delete [] SC0;
-	delete [] SC1;
-}
-
-template <typename T,typename AT,class VP>
-inline static void GaussianBlur_5x5_(etl::surface<T,AT,VP> &surface,AT *SC0,AT *SC1,AT *SC2,AT *SC3)
-{
-	int x,y,u,v,w,h;
-	AT Tmp1,Tmp2,SR0,SR1,SR2,SR3;
-
-	w=surface.get_w();
-	h=surface.get_h();
-
-	// Setup the row buffers
-	for(x=0;x<w;x++)SC0[x+2]=(AT)(surface[0][x])*24;
-
-	for(y=0;y<h+2;y++)
-	{
-		if(y>=h)
-			v=h-1;
-		else
-			v=y;
-
-		SR0=SR1=SR2=SR3=0;
-		SR0=(AT)(surface[v][0])*1.5;
-		for(x=0;x<w+2;x++)
-		{
-			if(x>=w)
-				u=w-1;
-			else
-				u=x;
-
-			// Row Machine
-			Tmp1=surface[v][u];
-			Tmp2=SR0+Tmp1;
-			SR0=Tmp1;
-			Tmp1=SR1+Tmp2;
-			SR1=Tmp2;
-			Tmp2=SR2+Tmp1;
-			SR2=Tmp1;
-			Tmp1=SR3+Tmp2;
-			SR3=Tmp2;
-
-			// Column Machine
-			Tmp2=SC0[x]+Tmp1;
-			SC0[x]=Tmp1;
-			Tmp1=SC1[x]+Tmp2;
-			SC1[x]=Tmp2;
-			Tmp2=SC2[x]+Tmp1;
-			SC2[x]=Tmp1;
-			if(y>1&&x>1)
-				surface[y-2][x-2]=(SC3[x]+Tmp2)/256;
-			SC3[x]=Tmp2;
-		}
-	}
-
-}
-
-template <typename T,typename AT,class VP>
-inline static void GaussianBlur_5x5(etl::surface<T,AT,VP> &surface)
-{
-	int w2=surface.get_w() + 2;
-
-	AT *SC0=new AT[w2];
-	AT *SC1=new AT[w2];
-	AT *SC2=new AT[w2];
-	AT *SC3=new AT[w2];
-
-	GaussianBlur_5x5_(surface,SC0,SC1,SC2,SC3);
-
-	delete [] SC0;
-	delete [] SC1;
-	delete [] SC2;
-	delete [] SC3;
-}
-
-template <typename T,typename AT,class VP>
-static void GaussianBlur_nxn(etl::surface<T,AT,VP> &surface,int n)
-{
-	int x,y,u,v,w,h;
-	int half_n=n/2,i;
-	float inv_divisor=pow(2.0,(n-1));
-	AT Tmp1,Tmp2;
-	inv_divisor=1.0/(inv_divisor*inv_divisor);
-
-	w=surface.get_w();
-	h=surface.get_h();
-	int w_half_n=w+half_n;
-    AT SR[n-1];
-	AT *SC[n-1];
-
-	for(i=0;i<n-1;i++)
-	{
-		SC[i]=new AT[w_half_n];
-		if(!SC[i])
-		{
-			throw(std::runtime_error(strprintf(__FILE__":%d:Malloc failure",__LINE__)));
-			return;
-		}
-	}
-
-	// Setup the first row
-//	for(x=0;x<w;x++)SC[0][x+half_n]=surface[0][x]*550.0;//*pow(2.0,(n-1))*(2.0/n);
-
-	for(y=0;y<h+half_n;y++)
-	{
-		if(y>=h)
-			v=h-1;
-		else
-			v=y;
-
-		if(y!=0)
-			memset(SR,0,(n-1)*sizeof(AT));
-
-//		SR[0]=surface[v][0]*(2.0-1.9/n);
-
-		for(x=0;x<w_half_n;x++)
-		{
-			if(x>=w)
-				u=w-1;
-			else
-				u=x;
-
-			Tmp1=surface[v][u];
-			// Row Machine
-			for(i=0;i<half_n;i++)
-			{
-				int idouble = i*2;
-				Tmp2=SR[idouble]+Tmp1;
-				SR[idouble]=Tmp1;
-				Tmp1=SR[idouble+1]+Tmp2;
-				SR[idouble+1]=Tmp2;
-			}
-
-			// Column Machine
-			for(i=0;i<half_n-1;i++)
-			{
-				int idouble = i*2;
-				Tmp2=SC[idouble][x]+Tmp1;
-				SC[idouble][x]=Tmp1;
-				Tmp1=SC[idouble+1][x]+Tmp2;
-				SC[idouble+1][x]=Tmp2;
-			}
-			Tmp2=SC[n-3][x]+Tmp1;
-			SC[n-3][x]=Tmp1;
-			if(y>=half_n&&x>=half_n)
-				surface[y-half_n][x-half_n]=(SC[n-2][x]+Tmp2)*inv_divisor;
-			SC[n-2][x]=Tmp2;
-		}
-	}
-
-	for(i=0;i<n-1;i++)
-		delete [] SC[i];
-}
-
-template <typename T,typename AT,class VP>
-static void GaussianBlur_2x1(etl::surface<T,AT,VP> &surface)
+template <typename T,class VP>
+static void GaussianBlur_2x1(synfig::surface<T,VP> &surface)
 {
 	int x,y,w,h;
-	AT Tmp1,Tmp2,SR0;
+	T Tmp1,Tmp2,SR0;
 
 	w = surface.get_w();
 	h = surface.get_h();
@@ -404,11 +205,11 @@ static void GaussianBlur_2x1(etl::surface<T,AT,VP> &surface)
 	}
 }
 
-template <typename T,typename AT,class VP>
-static void GaussianBlur_3x1(etl::surface<T,AT,VP> &surface)
+template <typename T,class VP>
+static void GaussianBlur_3x1(synfig::surface<T,VP> &surface)
 {
 	int x,y,w,h;
-	AT Tmp1,Tmp2,SR0,SR1;
+	T Tmp1,Tmp2,SR0,SR1;
 	w = surface.get_w();
 	h = surface.get_h();
 	
@@ -430,15 +231,15 @@ static void GaussianBlur_3x1(etl::surface<T,AT,VP> &surface)
 	}
 }
 
-template <typename T,typename AT,class VP>
-static void GaussianBlur_1x2(etl::surface<T,AT,VP> &surface)
+template <typename T,class VP>
+static void GaussianBlur_1x2(synfig::surface<T,VP> &surface)
 {
 	int x,y;
-	AT Tmp1,Tmp2,SR0;
+	T Tmp1,Tmp2,SR0;
 
 	for(x=0;x<surface.get_w();x++)
 	{
-		SR0 = zero<AT>();
+		SR0 = zero<T>();
 		for(y=0;y<surface.get_h();y++)
 		{
 			Tmp1=surface[y][x];
@@ -449,11 +250,11 @@ static void GaussianBlur_1x2(etl::surface<T,AT,VP> &surface)
 	}
 }
 
-template <typename T,typename AT,class VP>
-static void GaussianBlur_1x3(etl::surface<T,AT,VP> &surface)
+template <typename T,class VP>
+static void GaussianBlur_1x3(synfig::surface<T,VP> &surface)
 {
 	int x,y;
-	AT Tmp1,Tmp2,SR0,SR1;
+	T Tmp1,Tmp2,SR0,SR1;
 
 	for(x=0;x<surface.get_w();x++)
 	{
@@ -483,25 +284,19 @@ bool Blur::operator()(const Surface &surface,
 
 	if(w == 0 || h == 0 || resolution[0] == 0 || resolution[1] == 0) return false;
 
-	const Real	pw = resolution[0]/w,
-				ph = resolution[1]/h;
+	const Real pw = resolution[0] / w;
+	const Real ph = resolution[1] / h;
 
-	int	halfsizex = (int) (std::fabs(size[0]*.5/pw) + 1),
-		halfsizey = (int) (std::fabs(size[1]*.5/ph) + 1);
-
-	int x,y;
+	const Real halfsizex = std::fabs(size[0] * 0.5 / pw) + 1;
+	const Real halfsizey = std::fabs(size[1] * 0.5 / ph) + 1;
 
 	SuperCallback blurcall(cb,0,5000,5000);
 
 	Surface worksurface(w,h);
 
-	//synfig::info("Blur: check surface = %s", surface_valid(surface)?"true":"false");
-
 	// Premultiply the alpha
-	for(y=0;y<h;y++)
-	{
-		for(x=0;x<w;x++)
-		{
+	for (int y = 0; y < h; y++) {
+		for (int x = 0; x < w; x++) {
 			Color a = surface[y][x];
 			float aa = a.get_a();
 			a.set_r(a.get_r()*aa);
@@ -511,22 +306,27 @@ bool Blur::operator()(const Surface &surface,
 		}
 	}
 
-	switch(type)
-	{
+	Blur::Type parsed_type = Blur::Type(type);
+	if (type == Blur::DISC) {
+		if (!size[0] || !size[1] || w*h <= 2) {
+			//if we don't qualify for disc blur just use box blur
+			parsed_type = Blur::BOX;
+		}
+	}
+
+	switch(parsed_type) {
 	case Blur::DISC:	// D I S C ----------------------------------------------------------
 		{
-			int bw = halfsizex;
-			int bh = halfsizey;
+			int bw = int(halfsizex);
+			int bh = int(halfsizey);
 
 			if(size[0] && size[1] && w*h>2)
 			{
 				int x2,y2;
 				Surface tmp_surface(worksurface);
-
-				for(y=0;y<h;y++)
-				{
-					for(x=0;x<w;x++)
-					{
+				
+				for (int y = 0; y < h; y++) {
+					for (int x = 0; x < w; x++) {
 						//accumulate all the pixels in an ellipse of w,h about the current pixel
 						Color color=Color::alpha();
 						int total=0;
@@ -546,14 +346,8 @@ bool Blur::operator()(const Surface &surface,
 									continue;
 
 								//cap the pixel indices to inside the surface
-								int u= x+x2,
-									v= y+y2;
-
-								if( u < 0 )					u = 0;
-								if( u >= w ) u = w-1;
-
-								if( v < 0 ) 				v = 0;
-								if( v >= h ) v = h-1;
+								int u = synfig::clamp(x+x2, 0, w-1);
+								int v = synfig::clamp(y+y2, 0, h-1);
 
 								//accumulate the color, and # of pixels added in
 								color += tmp_surface[v][u];
@@ -561,67 +355,40 @@ bool Blur::operator()(const Surface &surface,
 							}
 						}
 
-						//blend the color with the original color
-						//if(get_amount()==1.0 && get_blend_method()==Color::BLEND_STRAIGHT)
-							worksurface[y][x]=color/total;
-						//else
-						//	worksurface[y][x]=Color::blend(color/total,tmp_surface[y][x],get_amount(),get_blend_method());
+						worksurface[y][x] = color/total;
 					}
-					if(!blurcall.amount_complete(y,h))
-					{
-						//if(cb)cb->error(strprintf(__FILE__"%d: Accelerated Renderer Failure",__LINE__));
+					if (!blurcall.amount_complete(y, h)) {
 						return false;
 					}
 				}
 				break;
 			}
 
-			//if we don't qualify for disc blur just use box blur
+			break;
 		}
 
 	case Blur::BOX: // B O X -------------------------------------------------------
 		{
 			//horizontal part
-			//synfig::info("Blur: Starting Box blur (surface valid %d)", (int)surface_valid(worksurface));
 
 			Surface temp_surface;
 			temp_surface.set_wh(w,h);
 
 			if(size[0])
 			{
-				int length = halfsizex;
-				length=std::max(1,length);
+				int length = std::max(1.0, halfsizex);
 
-				//synfig::info("Blur: hbox blur work -> temp %d", length);
-				etl::hbox_blur(worksurface.begin(),worksurface.end(),length,temp_surface.begin());
+				hbox_blur(worksurface.begin(),worksurface.end(),length,temp_surface.begin());
 			}
 			else temp_surface = worksurface;
-			//synfig::info("Blur: hbox finished");
-
-			//vertical part
-			//Surface temp_surface2;
-			//temp_surface2.set_wh(w,h);
 
 			if(size[1])
 			{
-				int length = halfsizey;
-				length = std::max(1,length);
+				int length = std::max(1.0, halfsizey);
 
-				//synfig::info("Blur: vbox blur temp -> work %d",length);
-				etl::vbox_blur(temp_surface.begin(),temp_surface.end(),length,worksurface.begin());
+				vbox_blur(temp_surface.begin(),temp_surface.end(),length,worksurface.begin());
 			}
 			else worksurface = temp_surface;
-			//synfig::info("Blur: vbox finished");
-
-			//blend with the original surface
-			/*int x,y;
-			for(y=0;y<h;y++)
-			{
-				for(x=0;x<w;x++)
-				{
-					worksurface[y][x]=temp_surface2[y][x];//Color::blend(temp_surface2[y][x],worksurface[y][x],get_amount(),get_blend_method());
-				}
-			}*/
 		}
 		break;
 
@@ -637,41 +404,25 @@ bool Blur::operator()(const Surface &surface,
 			Surface temp_surface;
 			temp_surface.set_wh(w,h);
 
-			//Surface temp_surface2;
-			//temp_surface2.set_wh(w,h);
-
 			//horizontal part
 			if(size[0])
 			{
-				Real length=std::fabs((float)w/(resolution[0]))*size[0]*0.5+1;
-				length=std::max(1.0,length);
+				Real length = std::max(1.0, halfsizex);
 
 				//two box blurs produces: 1 2 1
-				etl::hbox_blur(worksurface.begin(),w,h,(int)(length*3/4),temp_surface.begin());
-				etl::hbox_blur(temp_surface.begin(),w,h,(int)(length*3/4),worksurface.begin());
+				hbox_blur(worksurface.begin(),w,h,(int)(length*3/4),temp_surface.begin());
+				hbox_blur(temp_surface.begin(),w,h,(int)(length*3/4),worksurface.begin());
 			}
-			//else temp_surface2=worksurface;
 
 			//vertical part
 			if(size[1])
 			{
-				Real length=std::fabs((float)h/(resolution[1]))*size[1]*0.5+1;
-				length=std::max(1.0,length);
+				Real length = std::max(1.0, halfsizey);
 
 				//two box blurs produces: 1 2 1 on the horizontal 1 2 1
-				etl::vbox_blur(worksurface.begin(),w,h,(int)(length*3/4),temp_surface.begin());
-				etl::vbox_blur(temp_surface.begin(),w,h,(int)(length*3/4),worksurface.begin());
+				vbox_blur(worksurface.begin(),w,h,(int)(length*3/4),temp_surface.begin());
+				vbox_blur(temp_surface.begin(),w,h,(int)(length*3/4),worksurface.begin());
 			}
-			//else temp_surface2=temp_surface2;
-
-			/*int x,y;
-			for(y=0;y<h;y++)
-			{
-				for(x=0;x<w;x++)
-				{
-					worksurface[y][x]=temp_surface2[y][x];//Color::blend(temp_surface2[y][x],worksurface[y][x],get_amount(),get_blend_method());
-				}
-			}*/
 		}
 		break;
 
@@ -683,10 +434,9 @@ bool Blur::operator()(const Surface &surface,
 
 			if(size[0])
 			{
-				int length = halfsizex;
-				length = std::max(1,length);
+				int length = std::max(1.0, halfsizex);
 
-				etl::hbox_blur(worksurface.begin(),worksurface.end(),length,temp_surface.begin());
+				hbox_blur(worksurface.begin(),worksurface.end(),length,temp_surface.begin());
 			}
 			else temp_surface = worksurface;
 
@@ -696,20 +446,15 @@ bool Blur::operator()(const Surface &surface,
 
 			if(size[1])
 			{
-				int length = halfsizey;
-				length = std::max(1,length);
+				int length = std::max(1.0, halfsizey);
 
-				etl::vbox_blur(worksurface.begin(),worksurface.end(),length,temp_surface2.begin());
+				vbox_blur(worksurface.begin(),worksurface.end(),length,temp_surface2.begin());
 			}
 			else temp_surface2 = worksurface;
 
 			//blend the two together
-			int x,y;
-
-			for(y=0;y<h;y++)
-			{
-				for(x=0;x<w;x++)
-				{
+			for (int y = 0; y < h; y++) {
+				for (int x = 0; x < w; x++) {
 					worksurface[y][x] = (temp_surface[y][x]+temp_surface2[y][x])/2;//Color::blend((temp_surface[y][x]+temp_surface2[y][x])/2,worksurface[y][x],get_amount(),get_blend_method());
 				}
 			}
@@ -723,21 +468,10 @@ bool Blur::operator()(const Surface &surface,
 			#define GAUSSIAN_ADJUSTMENT		(0.05)
 			#endif
 
-			Real	pw = (Real)w/(resolution[0]);
-			Real 	ph = (Real)h/(resolution[1]);
-
 			Surface temp_surface;
 			Surface *gauss_surface;
 
-			//synfig::warning("Didn't crash yet b1");
-
-			//if(get_amount()==1.0 && get_blend_method()==Color::BLEND_STRAIGHT)
-				gauss_surface = &worksurface;
-			/*else
-			{
-				temp_surface = worksurface;
-				gauss_surface = &temp_surface;
-			}*/
+			gauss_surface = &worksurface;
 
             /* Squaring the pw and ph values
 			   is necessary to insure consistent
@@ -747,41 +481,34 @@ bool Blur::operator()(const Surface &surface,
 			   squares our rendertime.
 			   There has got to be a faster way...
 			*/
-			pw=pw*pw;
-			ph=ph*ph;
+			const Real pw2 = pw*pw;
+			const Real ph2 = ph*ph;
 
-			int bw = (int)(std::fabs(pw)*size[0]*GAUSSIAN_ADJUSTMENT+0.5);
-			int bh = (int)(std::fabs(ph)*size[1]*GAUSSIAN_ADJUSTMENT+0.5);
+			int bw = (int)(size[0]*GAUSSIAN_ADJUSTMENT/std::fabs(pw2) + 0.5);
+			int bh = (int)(size[1]*GAUSSIAN_ADJUSTMENT/std::fabs(ph2) + 0.5);
 			int max=bw+bh;
 
-			ColorAccumulator *SC0=new ColorAccumulator[w+2];
-			ColorAccumulator *SC1=new ColorAccumulator[w+2];
-			ColorAccumulator *SC2=new ColorAccumulator[w+2];
-			ColorAccumulator *SC3=new ColorAccumulator[w+2];
-
-			//synfig::warning("Didn't crash yet b2");
-			//int i = 0;
+			std::vector<Color> SC(4*(w+2));
+			Color* SC0 = &SC[0*(w+2)];
+			Color* SC1 = &SC[1*(w+2)];
+			Color* SC2 = &SC[2*(w+2)];
+			Color* SC3 = &SC[3*(w+2)];
 
 			while(bw&&bh)
 			{
 				if(!blurcall.amount_complete(max-(bw+bh),max)) {
-					delete [] SC0;
-					delete [] SC1;
-					delete [] SC2;
-					delete [] SC3;
-
 					return false;
 				}
 
 				if(bw>=4 && bh>=4)
 				{
-					etl::gaussian_blur_5x5_(gauss_surface->begin(),gauss_surface->get_w(),gauss_surface->get_h(),SC0,SC1,SC2,SC3);
+					gaussian_blur_5x5_(gauss_surface->begin(),gauss_surface->get_w(),gauss_surface->get_h(),SC0,SC1,SC2,SC3);
 					bw-=4,bh-=4;
 				}
 				else
 				if(bw>=2 && bh>=2)
 				{
-					etl::gaussian_blur_3x3(gauss_surface->begin(),gauss_surface->end());
+					gaussian_blur_3x3(gauss_surface->begin(),gauss_surface->end(), SC0, SC1);
 					bw-=2,bh-=2;
 				}
 				else
@@ -790,16 +517,10 @@ bool Blur::operator()(const Surface &surface,
 					GaussianBlur_2x2(*gauss_surface);
 					bw--,bh--;
 				}
-
-				//synfig::warning("Didn't crash yet bi - %d",i++);
 			}
 			while(bw)
 			{
 				if(!blurcall.amount_complete(max-(bw+bh),max)) {
-					delete [] SC0;
-					delete [] SC1;
-					delete [] SC2;
-					delete [] SC3;
 					return false;
 				}
 				if(bw>=2)
@@ -813,15 +534,10 @@ bool Blur::operator()(const Surface &surface,
 					GaussianBlur_2x1(*gauss_surface);
 					bw--;
 				}
-				//synfig::warning("Didn't crash yet bi - %d",i++);
 			}
 			while(bh)
 			{
 				if(!blurcall.amount_complete(max-(bw+bh),max)) {
-					delete [] SC0;
-					delete [] SC1;
-					delete [] SC2;
-					delete [] SC3;
 					return false;
 				}
 				if(bh>=2)
@@ -835,22 +551,7 @@ bool Blur::operator()(const Surface &surface,
 					GaussianBlur_1x2(*gauss_surface);
 					bh--;
 				}
-				//synfig::warning("Didn't crash yet bi - %d",i++);
 			}
-
-			delete [] SC0;
-			delete [] SC1;
-			delete [] SC2;
-			delete [] SC3;
-
-			/*if(get_amount()!=1.0 || get_blend_method()!=Color::BLEND_STRAIGHT)
-			{
-				int x,y;
-				for(y=0;y<renddesc.get_h();y++)
-					for(x=0;x<renddesc.get_w();x++)
-						worksurface[y][x]=Color::blend(temp_surface[y][x],worksurface[y][x],get_amount(),get_blend_method());
-			}*/
-			//synfig::warning("Didn't crash yet b end",i++);
 		}
 		break;
 
@@ -861,14 +562,11 @@ bool Blur::operator()(const Surface &surface,
 	// Scale up the alpha
 
 	//be sure the surface is of the correct size
-	//surface->set_wh(renddesc.get_w(),renddesc.get_h());
 	out.set_wh(w,h);
 
 	//divide out the alpha
-	for(y=0;y<h;y++)
-	{
-		for(x=0;x<w;x++)
-		{
+	for (int y = 0; y < h; y++) {
+		for (int x = 0; x < w; x++) {
 			Color a = worksurface[y][x];
 			if(a.get_a())
 			{
@@ -889,44 +587,52 @@ bool Blur::operator()(const Surface &surface,
 
 //////
 
-bool Blur::operator()(const etl::surface<float> &surface,
+bool Blur::operator()(const synfig::surface<float> &surface,
 					  const synfig::Vector &resolution,
-					  etl::surface<float> &out) const
+					  synfig::surface<float> &out) const
 {
-	int w = surface.get_w(),
-		h = surface.get_h();
+	if (&surface == &out) {
+		synfig::error(_("Internal error: Blur(surface of float): in and out surfaces cannot be the same"));
+		return false;
+	}
+
+	const int w = surface.get_w();
+	const int h = surface.get_h();
 
 	if(w == 0 || h == 0 || resolution[0] == 0 || resolution[1] == 0) return false;
 
-	const Real	pw = resolution[0]/w,
-				ph = resolution[1]/h;
+	const Real pw = resolution[0] / w;
+	const Real ph = resolution[1] / h;
 
-	int	halfsizex = (int) (std::fabs(size[0]*.5/pw) + 1),
-		halfsizey = (int) (std::fabs(size[1]*.5/ph) + 1);
-	int x,y;
+	const Real halfsizex = std::fabs(size[0] * 0.5 / pw) + 1;
+	const Real halfsizey = std::fabs(size[1] * 0.5 / ph) + 1;
 
 	SuperCallback blurcall(cb,0,5000,5000);
 
-	etl::surface<float> worksurface(surface);
+	out = surface;
 
 	//don't need to premultiply because we are dealing with ONLY alpha
 
-	switch(type)
-	{
+	Blur::Type parsed_type = Blur::Type(type);
+	if (type == Blur::DISC) {
+		if (!size[0] || !size[1] || w*h <= 2) {
+			//if we don't qualify for disc blur just use box blur
+			parsed_type = Blur::BOX;
+		}
+	}
+
+	switch (parsed_type) {
 	case Blur::DISC:	// D I S C ----------------------------------------------------------
 		{
-			int bw = halfsizex;
-			int bh = halfsizey;
+			int bw = int(halfsizex);
+			int bh = int(halfsizey);
 
 			if(size[0] && size[1] && w*h>2)
 			{
 				int x2,y2;
-				etl::surface<float> tmp_surface(worksurface);
-
-				for(y=0;y<h;y++)
-				{
-					for(x=0;x<w;x++)
-					{
+			
+				for (int y = 0; y < h; y++) {
+					for (int x = 0; x < w; x++) {
 						//accumulate all the pixels in an ellipse of w,h about the current pixel
 						float a = 0;
 						int total=0;
@@ -946,75 +652,47 @@ bool Blur::operator()(const etl::surface<float> &surface,
 									continue;
 
 								//cap the pixel indices to inside the surface
-								int u= x+x2,
-									v= y+y2;
-
-								if( u < 0 )					u = 0;
-								if( u >= w ) u = w-1;
-
-								if( v < 0 ) 				v = 0;
-								if( v >= h ) v = h-1;
+								int u = synfig::clamp(x+x2, 0, w-1);
+								int v = synfig::clamp(y+y2, 0, h-1);
 
 								//accumulate the color, and # of pixels added in
-								a += tmp_surface[v][u];
+								a += surface[v][u];
 								total++;
 							}
 						}
 
-						//blend the color with the original color
-						//if(get_amount()==1.0 && get_blend_method()==Color::BLEND_STRAIGHT)
-							worksurface[y][x]=a/total;
-						//else
-						//	worksurface[y][x]=Color::blend(color/total,tmp_surface[y][x],get_amount(),get_blend_method());
+						out[y][x] = a/total;
 					}
-					if(!blurcall.amount_complete(y,h))
-					{
-						//if(cb)cb->error(strprintf(__FILE__"%d: Accelerated Renderer Failure",__LINE__));
+					if (!blurcall.amount_complete(y, h)) {
 						return false;
 					}
 				}
 				break;
 			}
 
-			//if we don't qualify for disc blur just use box blur
+			break;
 		}
 
 	case Blur::BOX: // B O X -------------------------------------------------------
 		{
 			//horizontal part
-			etl::surface<float> temp_surface;
+			synfig::surface<float> temp_surface;
 			temp_surface.set_wh(w,h);
 
 			if(size[0])
 			{
-				int length = halfsizex;
-				length=std::max(1,length);
+				int length = std::max(1.0, halfsizex);
 
-				etl::hbox_blur(worksurface.begin(),worksurface.end(),length,temp_surface.begin());
+				hbox_blur(surface.begin(), surface.end(), length, temp_surface.begin());
 			}
-			else temp_surface = worksurface;
-
-			//vertical part
-			//etl::surface<float> temp_surface2;
-			//temp_surface2.set_wh(w,h);
+			else temp_surface = surface;
 
 			if(size[1])
 			{
-				int length = halfsizey;
-				length = std::max(1,length);
-				etl::vbox_blur(temp_surface.begin(),temp_surface.end(),length,worksurface.begin());
+				int length = std::max(1.0, halfsizey);
+				vbox_blur(temp_surface.begin(), temp_surface.end(), length, out.begin());
 			}
-			else worksurface = temp_surface;
-
-			//blend with the original surface
-			/*int x,y;
-			for(y=0;y<h;y++)
-			{
-				for(x=0;x<w;x++)
-				{
-					worksurface[y][x]=temp_surface2[y][x];//Color::blend(temp_surface2[y][x],worksurface[y][x],get_amount(),get_blend_method());
-				}
-			}*/
+			else out = temp_surface;
 		}
 		break;
 
@@ -1027,83 +705,63 @@ bool Blur::operator()(const etl::surface<float> &surface,
 				1	2	1
 			*/
 
-			etl::surface<float> temp_surface;
+			synfig::surface<float> temp_surface;
 			temp_surface.set_wh(w,h);
 
-			//etl::surface<float> temp_surface2;
-			//temp_surface2.set_wh(w,h);
-
 			//horizontal part
 			if(size[0])
 			{
-				Real length=std::fabs((float)w/(resolution[0]))*size[0]*0.5+1;
-				length=std::max(1.0,length);
+				Real length = std::max(1.0, halfsizex);
 
 				//two box blurs produces: 1 2 1
-				etl::hbox_blur(worksurface.begin(),w,h,(int)(length*3/4),temp_surface.begin());
-				etl::hbox_blur(temp_surface.begin(),w,h,(int)(length*3/4),worksurface.begin());
+				hbox_blur(out.begin(), w, h, (int)(length*3/4), temp_surface.begin());
+				hbox_blur(temp_surface.begin(), w, h, (int)(length*3/4), out.begin());
 			}
-			//else temp_surface2=worksurface;
 
 			//vertical part
 			if(size[1])
 			{
-				Real length=std::fabs((float)h/(resolution[1]))*size[1]*0.5+1;
-				length=std::max(1.0,length);
+				Real length = std::max(1.0, halfsizey);
 
 				//two box blurs produces: 1 2 1 on the horizontal 1 2 1
-				etl::vbox_blur(worksurface.begin(),w,h,(int)(length*3/4),temp_surface.begin());
-				etl::vbox_blur(temp_surface.begin(),w,h,(int)(length*3/4),worksurface.begin());
+				vbox_blur(out.begin(), w, h, (int)(length*3/4), temp_surface.begin());
+				vbox_blur(temp_surface.begin(), w, h, (int)(length*3/4), out.begin());
 			}
-			//else temp_surface2=temp_surface2;
-
-			/*int x,y;
-			for(y=0;y<h;y++)
-			{
-				for(x=0;x<w;x++)
-				{
-					worksurface[y][x]=temp_surface2[y][x];//Color::blend(temp_surface2[y][x],worksurface[y][x],get_amount(),get_blend_method());
-				}
-			}*/
 		}
 		break;
 
 	case Blur::CROSS: // C R O S S  -------------------------------------------------------
 		{
 			//horizontal part
-			etl::surface<float> temp_surface;
-			temp_surface.set_wh(worksurface.get_w(),worksurface.get_h());
+			synfig::surface<float> temp_surface;
+			synfig::surface<float>& h_surface(temp_surface);
 
 			if(size[0])
 			{
-				int length = halfsizex;
-				length = std::max(1,length);
+				int length = std::max(1.0, halfsizex);
 
-				etl::hbox_blur(worksurface.begin(),worksurface.end(),length,temp_surface.begin());
+				temp_surface.set_wh(w, h);
+				hbox_blur(out.begin(), out.end(), length, temp_surface.begin());
 			}
-			else temp_surface = worksurface;
+			else h_surface = out;
 
 			//vertical part
-			etl::surface<float> temp_surface2;
-			temp_surface2.set_wh(worksurface.get_w(),worksurface.get_h());
+			synfig::surface<float> temp_surface2;
+			synfig::surface<float>& v_surface(temp_surface2);
 
 			if(size[1])
 			{
-				int length = halfsizey;
-				length = std::max(1,length);
+				int length = std::max(1.0, halfsizey);
 
-				etl::vbox_blur(worksurface.begin(),worksurface.end(),length,temp_surface2.begin());
+				temp_surface2.set_wh(w, h);
+				vbox_blur(out.begin(), out.end(), length, temp_surface2.begin());
 			}
-			else temp_surface2 = worksurface;
+			else v_surface = out;
 
 			//blend the two together
-			int x,y;
-
-			for(y=0;y<h;y++)
-			{
-				for(x=0;x<w;x++)
-				{
-					worksurface[y][x] = (temp_surface[y][x]+temp_surface2[y][x])/2;//Color::blend((temp_surface[y][x]+temp_surface2[y][x])/2,worksurface[y][x],get_amount(),get_blend_method());
+			for (int y = 0; y < h; y++) {
+				for (int x = 0; x < w; x++) {
+					out[y][x] = (h_surface[y][x] + v_surface[y][x]) / 2;
 				}
 			}
 
@@ -1116,21 +774,11 @@ bool Blur::operator()(const etl::surface<float> &surface,
 			#define GAUSSIAN_ADJUSTMENT		(0.05)
 			#endif
 
-			Real	pw = (Real)w/(resolution[0]);
-			Real 	ph = (Real)h/(resolution[1]);
+			synfig::surface<float> *gauss_surface;
 
-			//etl::surface<float> temp_surface;
-			etl::surface<float> *gauss_surface;
+			gauss_surface = &out;
 
-			//if(get_amount()==1.0 && get_blend_method()==Color::BLEND_STRAIGHT)
-				gauss_surface = &worksurface;
-			/*else
-			{
-				temp_surface = worksurface;
-				gauss_surface = &temp_surface;
-			}*/
-
-            /* Squaring the pw and ph values
+			/* Squaring the pw and ph values
 			   is necessary to insure consistent
 			   results when rendered to different
 			   resolutions.
@@ -1138,45 +786,34 @@ bool Blur::operator()(const etl::surface<float> &surface,
 			   squares our rendertime.
 			   There has got to be a faster way...
 			*/
-			pw=pw*pw;
-			ph=ph*ph;
+			const Real pw2 = pw*pw;
+			const Real ph2 = ph*ph;
 
-			int bw = (int)(std::fabs(pw)*size[0]*GAUSSIAN_ADJUSTMENT+0.5);
-			int bh = (int)(std::fabs(ph)*size[1]*GAUSSIAN_ADJUSTMENT+0.5);
+			int bw = (int)(size[0]*GAUSSIAN_ADJUSTMENT/std::fabs(pw2) + 0.5);
+			int bh = (int)(size[1]*GAUSSIAN_ADJUSTMENT/std::fabs(ph2) + 0.5);
 			int max=bw+bh;
 
-			float *SC0=new float[w+2];
-			float *SC1=new float[w+2];
-			float *SC2=new float[w+2];
-			float *SC3=new float[w+2];
-
-			memset(SC0,0,(w+2)*sizeof(float));
-			memset(SC0,0,(w+2)*sizeof(float));
-			memset(SC0,0,(w+2)*sizeof(float));
-			memset(SC0,0,(w+2)*sizeof(float));
-
-			//int i = 0;
+			std::vector<float> SC(4*(w+2));
+			float* SC0 = &SC[0*(w+2)];
+			float* SC1 = &SC[1*(w+2)];
+			float* SC2 = &SC[2*(w+2)];
+			float* SC3 = &SC[3*(w+2)];
 
 			while(bw&&bh)
 			{
 				if (!blurcall.amount_complete(max-(bw+bh),max)) {
-					delete [] SC0;
-					delete [] SC1;
-					delete [] SC2;
-					delete [] SC3;
-
 					return false;
 				}
 
 				if(bw>=4 && bh>=4)
 				{
-					etl::gaussian_blur_5x5_(gauss_surface->begin(),gauss_surface->get_w(),gauss_surface->get_h(),SC0,SC1,SC2,SC3);
+					gaussian_blur_5x5_(gauss_surface->begin(),gauss_surface->get_w(),gauss_surface->get_h(),SC0,SC1,SC2,SC3);
 					bw-=4,bh-=4;
 				}
 				else
 				if(bw>=2 && bh>=2)
 				{
-					etl::gaussian_blur_3x3(gauss_surface->begin(),gauss_surface->end());
+					gaussian_blur_3x3(gauss_surface->begin(),gauss_surface->end(), SC0, SC1);
 					bw-=2,bh-=2;
 				}
 				else
@@ -1190,11 +827,6 @@ bool Blur::operator()(const etl::surface<float> &surface,
 			while(bw)
 			{
 				if (!blurcall.amount_complete(max-(bw+bh),max)) {
-					delete [] SC0;
-					delete [] SC1;
-					delete [] SC2;
-					delete [] SC3;
-
 					return false;
 				}
 				if(bw>=2)
@@ -1213,11 +845,6 @@ bool Blur::operator()(const etl::surface<float> &surface,
 			while(bh)
 			{
 				if (!blurcall.amount_complete(max-(bw+bh),max)) {
-					delete [] SC0;
-					delete [] SC1;
-					delete [] SC2;
-					delete [] SC3;
-
 					return false;
 				}
 				if(bh>=2)
@@ -1232,19 +859,6 @@ bool Blur::operator()(const etl::surface<float> &surface,
 					bh--;
 				}
 			}
-
-			delete [] SC0;
-			delete [] SC1;
-			delete [] SC2;
-			delete [] SC3;
-
-			/*if(get_amount()!=1.0 || get_blend_method()!=Color::BLEND_STRAIGHT)
-			{
-				int x,y;
-				for(y=0;y<renddesc.get_h();y++)
-					for(x=0;x<renddesc.get_w();x++)
-						worksurface[y][x]=Color::blend(temp_surface[y][x],worksurface[y][x],get_amount(),get_blend_method());
-			}*/
 		}
 		break;
 
@@ -1252,12 +866,7 @@ bool Blur::operator()(const etl::surface<float> &surface,
 			break;
 	}
 
-	//be sure the surface is of the correct size
-	//surface->set_wh(renddesc.get_w(),renddesc.get_h());
-	out.set_wh(w,h);
-
 	//divide out the alpha - don't need to cause we rock
-	out = worksurface;
 
 	//we are FRIGGGIN done....
 	blurcall.amount_complete(100,100);
