@@ -2,22 +2,25 @@
 /*!	\file layer.cpp
 **	\brief Layer class implementation
 **
-**	$Id$
-**
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
 **	Copyright (c) 2007, 2008 Chris Moore
 **	Copyright (c) 2011-2013 Carlos López
 **
-**	This package is free software; you can redistribute it and/or
-**	modify it under the terms of the GNU General Public License as
-**	published by the Free Software Foundation; either version 2 of
-**	the License, or (at your option) any later version.
+**	This file is part of Synfig.
 **
-**	This package is distributed in the hope that it will be useful,
+**	Synfig is free software: you can redistribute it and/or modify
+**	it under the terms of the GNU General Public License as published by
+**	the Free Software Foundation, either version 2 of the License, or
+**	(at your option) any later version.
+**
+**	Synfig is distributed in the hope that it will be useful,
 **	but WITHOUT ANY WARRANTY; without even the implied warranty of
-**	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
-**	General Public License for more details.
+**	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+**	GNU General Public License for more details.
+**
+**	You should have received a copy of the GNU General Public License
+**	along with Synfig.  If not, see <https://www.gnu.org/licenses/>.
 **	\endlegal
 */
 /* ========================================================================= */
@@ -48,7 +51,6 @@
 #include "transform.h"
 
 #include "layers/layer_composite.h"
-#include "layers/layer_bitmap.h"
 #include "layers/layer_duplicate.h"
 #include "layers/layer_filtergroup.h"
 #include "layers/layer_group.h"
@@ -73,7 +75,6 @@
 
 /* === U S I N G =========================================================== */
 
-using namespace etl;
 using namespace synfig;
 
 /* === G L O B A L S ======================================================= */
@@ -129,7 +130,7 @@ Layer::subsys_init()
 				  class::get_register_version())
 
 	INCLUDE_LAYER(Layer_SolidColor);
-		LAYER_ALIAS(Layer_SolidColor,	"solid_color");
+		LAYER_ALIAS(Layer_SolidColor,	"SolidColor"); // old name, previous to version 1.5.2
 	INCLUDE_LAYER(Layer_FilterGroup);
 	INCLUDE_LAYER(Layer_Group);
 		LAYER_ALIAS(Layer_Group,		"paste_canvas");
@@ -138,7 +139,7 @@ Layer::subsys_init()
 	INCLUDE_LAYER(Layer_Polygon);
 		LAYER_ALIAS(Layer_Polygon,		"Polygon");
 	INCLUDE_LAYER(Layer_MotionBlur);
-		LAYER_ALIAS(Layer_MotionBlur,	"motion_blur");
+		LAYER_ALIAS(Layer_MotionBlur,	"MotionBlur"); // old name, previous to version 1.5.2
 	INCLUDE_LAYER(Layer_Duplicate);
 	INCLUDE_LAYER(Layer_Skeleton);
 	INCLUDE_LAYER(Layer_SkeletonDeformation);
@@ -164,8 +165,8 @@ Layer::Layer():
 	optimized_(false),
 	exclude_from_rendering_(false),
 	param_z_depth(Real(0.0f)),
-	time_mark(Time::end()),
-	outline_grow_mark(0.0)
+	time_mark_(Time::end()),
+	outline_grow_mark_(0.0)
 {
 	_layer_counter.counter++;
 	SET_INTERPOLATION_DEFAULTS();
@@ -203,7 +204,7 @@ synfig::Layer::~Layer()
 }
 
 void
-synfig::Layer::set_canvas(etl::loose_handle<Canvas> x)
+synfig::Layer::set_canvas(Canvas::LooseHandle x)
 {
 	if(canvas_!=x)
 	{
@@ -217,7 +218,7 @@ synfig::Layer::set_canvas(etl::loose_handle<Canvas> x)
 						*this,
 						&Layer::set_canvas
 					),
-					etl::loose_handle<synfig::Canvas>(0)
+					Canvas::LooseHandle(0)
 				)
 			);
 		}
@@ -244,7 +245,7 @@ synfig::Layer::on_dynamic_param_changed(const String & /* param */)
 	{ }
 
 
-etl::loose_handle<synfig::Canvas>
+Canvas::LooseHandle
 synfig::Layer::get_canvas()const
 {
 	return canvas_;
@@ -309,7 +310,7 @@ Layer::dynamic_param_changed(const String &param)
 }
 
 bool
-Layer::connect_dynamic_param(const String& param, etl::loose_handle<ValueNode> value_node)
+Layer::connect_dynamic_param(const String& param, ValueNode::LooseHandle value_node)
 {
 	if (!value_node) return disconnect_dynamic_param(param);
 
@@ -330,7 +331,7 @@ Layer::connect_dynamic_param(const String& param, etl::loose_handle<ValueNode> v
 		// connection was being deleted.  now we search the parameter
 		// list to see if another parameter uses the same valuenode
 		DynamicParamList::const_iterator iter;
-		for (iter = dynamic_param_list().begin(); iter != dynamic_param_list().end(); iter++)
+		for (iter = dynamic_param_list().begin(); iter != dynamic_param_list().end(); ++iter)
 			if (iter->second == previous)
 				break;
 		if (iter == dynamic_param_list().end())
@@ -363,7 +364,7 @@ Layer::disconnect_dynamic_param(const String& param)
 		// connection was being deleted.  now we search the parameter
 		// list to see if another parameter uses the same valuenode
 		DynamicParamList::const_iterator iter;
-		for (iter = dynamic_param_list().begin(); iter != dynamic_param_list().end(); iter++)
+		for (iter = dynamic_param_list().begin(); iter != dynamic_param_list().end(); ++iter)
 			if (iter->second == previous)
 				break;
 		if (iter == dynamic_param_list().end())
@@ -379,8 +380,8 @@ Layer::disconnect_dynamic_param(const String& param)
 void
 Layer::on_changed()
 {
-	if (getenv("SYNFIG_DEBUG_ON_CHANGED"))
-		printf("%s:%d Layer::on_changed()\n", __FILE__, __LINE__);
+	DEBUG_LOG("SYNFIG_DEBUG_ON_CHANGED",
+		"%s:%d Layer::on_changed()\n", __FILE__, __LINE__);
 
 	clear_time_mark();
 	Node::on_changed();
@@ -603,12 +604,12 @@ Layer::reset_version()
 
 
 void
-Layer::set_time(IndependentContext context, Time time)const
+Layer::set_time(IndependentContext context, Time time)
 {
 	Layer::ParamList params;
 	Layer::DynamicParamList::const_iterator iter;
-	// For each parameter of the layer sets the time by the operator()(time)
-	for(iter=dynamic_param_list().begin();iter!=dynamic_param_list().end();iter++)
+	// For each parameter of the layer sets the value by the operator()(time)
+	for (iter = dynamic_param_list().begin(); iter != dynamic_param_list().end(); ++iter)
 		params[iter->first]=(*iter->second)(time);
 	// Sets the modified parameter list to the current context layer
 	const_cast<Layer*>(this)->set_param_list(params);
@@ -637,14 +638,14 @@ Layer::load_resources_vfunc(IndependentContext context, Time time)const
 }
 
 void
-Layer::set_outline_grow(IndependentContext context, Real outline_grow)const
+Layer::set_outline_grow(IndependentContext context, Real outline_grow)
 {
 	set_outline_grow_mark(outline_grow);
 	set_outline_grow_vfunc(context, outline_grow);
 }
 
 void
-Layer::set_outline_grow_vfunc(IndependentContext context, Real outline_grow)const
+Layer::set_outline_grow_vfunc(IndependentContext context, Real outline_grow)
 {
 	context.set_outline_grow(outline_grow);
 }
@@ -833,7 +834,7 @@ Layer::accelerated_render(Context context,Surface *surface,int quality, const Re
 {
 	RENDER_TRANSFORMED_IF_NEED(__FILE__, __LINE__)
 
-	handle<Target_Scanline> target=surface_target_scanline(surface);
+	Target_Scanline::Handle target = surface_target_scanline(surface);
 	if(!target)
 	{
 		if(cb)cb->error(_("Unable to create surface target"));
@@ -888,14 +889,14 @@ Layer::build_rendering_task_vfunc(Context context)const
 {
 	rendering::TaskLayer::Handle task = new rendering::TaskLayer();
 	// TODO: This is not thread-safe
-	//task->layer = const_cast<Layer*>(this);//clone(NULL);
-	task->layer = clone(NULL);
+	//task->layer = const_cast<Layer*>(this);//clone(nullptr);
+	task->layer = clone(nullptr);
 	task->layer->set_canvas(get_canvas());
 
 	Real amount = Context::z_depth_visibility(context.get_params(), *this);
 	if (approximate_not_equal(amount, 1.0) && task->layer.type_is<Layer_Composite>())
 	{
-		//task->layer = task->layer->clone(NULL);
+		//task->layer = task->layer->clone(nullptr);
 		etl::handle<Layer_Composite> composite = etl::handle<Layer_Composite>::cast_dynamic(task->layer);
 		composite->set_amount( composite->get_amount()*amount );
 	}
@@ -928,7 +929,7 @@ Layer::get_param_vocab()const
 {
 	Layer::Vocab ret;
 
-	ret.push_back(ParamDesc(param_z_depth,"z_depth")
+	ret.push_back(ParamDesc("z_depth")
 		.set_local_name(_("Z Depth"))
 		.set_animation_only(true)
 		.set_description(_("Modifies the position of the layer in the layer stack"))
@@ -989,7 +990,7 @@ Layer::get_param_local_name(const String &param_name)const
 {
 	ParamVocab vocab = get_param_vocab();
 	// loop to find the parameter in the parameter vocab - this gives us its local name
-	for (ParamVocab::iterator iter = vocab.begin(); iter != vocab.end(); iter++)
+	for (ParamVocab::iterator iter = vocab.begin(); iter != vocab.end(); ++iter)
 		if (iter->get_name() == param_name)
 			return iter->get_local_name();
 	return String();
@@ -1006,18 +1007,17 @@ synfig::Layer::get_parent_paste_canvas_layer()const
 		for(iter=parent_canvas->begin();iter!=parent_canvas->end();++iter)
 		{
 			Layer::LooseHandle layer=iter->get();
-			if(dynamic_cast<Layer_PasteCanvas*>(layer.get()) != NULL)
+			if(Layer_PasteCanvas* paste_canvas = dynamic_cast<Layer_PasteCanvas*>(layer.get()))
 			{
-				Layer_PasteCanvas* paste_canvas(static_cast<Layer_PasteCanvas*>(layer.get()));
 				Canvas::Handle sub_canvas=paste_canvas->get_sub_canvas();
 				if(sub_canvas==canvas)
 					return layer;
 			}
 		}
 		synfig::warning("Layer's canvas has parent canvas but I can't find a proper Layer_PasteCanvas in it");
-		return NULL;
+		return nullptr;
 	}
-	return NULL;
+	return nullptr;
 }
 
 String
@@ -1036,26 +1036,30 @@ using Glib::RefPtr;
 void Layer::on_file_changed(const RefPtr<Gio::File> &/*file*/, const RefPtr<Gio::File> &/*other_file*/, Gio::FileMonitorEvent event) {
 	if (event == Gio::FILE_MONITOR_EVENT_CHANGES_DONE_HINT)
 	{
-		synfig::warning("file changed! (" + monitored_path + ")");
+		synfig::warning("file changed! (%s)", monitored_path.u8_str());
 		set_param("filename", ValueBase("")); // first clear filename to force image reload
-		Importer::forget(get_canvas()->get_file_system()->get_identifier(monitored_path)); // clear file in list of loaded files
-		set_param("filename", ValueBase(monitored_path));
+		Importer::forget(get_canvas()->get_file_system()->get_identifier(monitored_path.u8string())); // clear file in list of loaded files
+		set_param("filename", ValueBase(monitored_path.u8string()));
 		get_canvas()->signal_changed()();
 	}
 }
 
-bool Layer::monitor(const std::string& path) { // append file monitor (returns true on success, false on fail)
+bool Layer::monitor(const filesystem::Path& path) { // append file monitor (returns true on success, false on fail)
 	if (file_monitor)
 	{
-		synfig::warning("File monitor for file '" + path + "' is already attached!");
+		synfig::warning("File monitor for file '%s' is already attached!", path.u8_str());
 		return false;
 	}
 
-	RefPtr<Gio::File> file = Gio::File::create_for_path(path);
+	const bool is_network_shared_folder = path.root_name().u8string().substr(0, 2) == "\\\\";
+	std::string uri = !is_network_shared_folder ? "file://" : "";
+	uri += path.cleanup().u8string();
+
+	RefPtr<Gio::File> file = Gio::File::create_for_uri(uri);
 	file_monitor = file->monitor_file(); // defaults to Gio::FileMonitorFlags::FILE_MONITOR_NONE
 	monitor_connection = file_monitor->signal_changed().connect(sigc::mem_fun(*this, &Layer::on_file_changed));
-	monitored_path = path;
-	synfig::info("File monitor attached to file: (" + path + ")");
+	monitored_path = path.cleanup();
+	synfig::info("File monitor attached to file: (%s)", path.u8_str());
 
 	return true;
 }
