@@ -2,21 +2,24 @@
 /*!	\file rect.h
 **	\brief Rectangle Class
 **
-**	$Id$
-**
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
 **	Copyright (c) 2007, 2008 Chris Moore
 **
-**	This package is free software; you can redistribute it and/or
-**	modify it under the terms of the GNU General Public License as
-**	published by the Free Software Foundation; either version 2 of
-**	the License, or (at your option) any later version.
+**	This file is part of Synfig.
 **
-**	This package is distributed in the hope that it will be useful,
+**	Synfig is free software: you can redistribute it and/or modify
+**	it under the terms of the GNU General Public License as published by
+**	the Free Software Foundation, either version 2 of the License, or
+**	(at your option) any later version.
+**
+**	Synfig is distributed in the hope that it will be useful,
 **	but WITHOUT ANY WARRANTY; without even the implied warranty of
-**	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
-**	General Public License for more details.
+**	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+**	GNU General Public License for more details.
+**
+**	You should have received a copy of the GNU General Public License
+**	along with Synfig.  If not, see <https://www.gnu.org/licenses/>.
 **	\endlegal
 */
 /* ========================================================================= */
@@ -98,6 +101,14 @@ public:
 			minx(o.minx), miny(o.miny), maxx(o.maxx), maxy(o.maxy) { }
 	rect(const rect<T> &o):
 			minx(o.minx), miny(o.miny), maxx(o.maxx), maxy(o.maxy) { }
+	rect<T>& operator=(const rect<T>& o)
+	{
+		minx = o.minx;
+		maxx = o.maxx;
+		miny = o.miny;
+		maxy = o.maxy;
+		return *this;
+	}
 
 	template<typename F>
 	rect(
