@@ -2,20 +2,23 @@
 /*!	\file synfig/rendering/renderer.cpp
 **	\brief Renderer
 **
-**	$Id$
-**
 **	\legal
 **	......... ... 2015-2018 Ivan Mahonin
 **
-**	This package is free software; you can redistribute it and/or
-**	modify it under the terms of the GNU General Public License as
-**	published by the Free Software Foundation; either version 2 of
-**	the License, or (at your option) any later version.
+**	This file is part of Synfig.
 **
-**	This package is distributed in the hope that it will be useful,
+**	Synfig is free software: you can redistribute it and/or modify
+**	it under the terms of the GNU General Public License as published by
+**	the Free Software Foundation, either version 2 of the License, or
+**	(at your option) any later version.
+**
+**	Synfig is distributed in the hope that it will be useful,
 **	but WITHOUT ANY WARRANTY; without even the implied warranty of
-**	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
-**	General Public License for more details.
+**	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+**	GNU General Public License for more details.
+**
+**	You should have received a copy of the GNU General Public License
+**	along with Synfig.  If not, see <https://www.gnu.org/licenses/>.
 **	\endlegal
 */
 /* ========================================================================= */
@@ -32,11 +35,8 @@
 #include <algorithm> // std::sort
 #include <cstdlib>
 #include <climits>
-
 #include <typeinfo>
 
-#include <ETL/stringf>
-
 #include <synfig/general.h>
 #include <synfig/localization.h>
 #include <synfig/threadpool.h>
@@ -492,7 +492,7 @@ Renderer::optimize(Task::List &list) const
 	#endif
 
 	#ifdef DEBUG_OPTIMIZATION_COUNTERS
-	debug::Log::info("", "optimize %d tasks", count_tasks(list));
+	debug::Log::info({}, "optimize %d tasks", count_tasks(list));
 	#endif
 
 	int current_category_id = 0;
@@ -516,7 +516,7 @@ Renderer::optimize(Task::List &list) const
 				break;
 			}
 			#ifdef DEBUG_OPTIMIZATION
-			log("", list, etl::strprintf("after category %d prepared", prepared_category_id));
+			log("", list, strprintf("after category %d prepared", prepared_category_id));
 			#endif
 		}
 		prepared_category_id = current_category_id;
@@ -574,19 +574,19 @@ Renderer::optimize(Task::List &list) const
 		}
 
 		#ifdef DEBUG_OPTIMIZATION
-		log("", list, etl::strprintf("before optimize category %d index %d", current_category_id, current_optimizer_index));
+		log("", list, strprintf("before optimize category %d index %d", current_category_id, current_optimizer_index));
 		#endif
 
 		#ifdef DEBUG_OPTIMIZATION_MEASURE
-		debug::Measure t(etl::strprintf("optimize category %d index %d", current_category_id, current_optimizer_index));
+		debug::Measure t(strprintf("optimize category %d index %d", current_category_id, current_optimizer_index));
 		#endif
 
 		#ifdef DEBUG_OPTIMIZATION_COUNTERS
 		std::atomic<int> calls_count(0), *calls_count_ptr = &calls_count;
 		std::atomic<int> optimizations_count(0), *optimizations_count_ptr = &optimizations_count;
 		#else
-		std::atomic<int> *calls_count_ptr = NULL;
-		std::atomic<int> *optimizations_count_ptr = NULL;
+		std::atomic<int>* calls_count_ptr = nullptr;
+		std::atomic<int>* optimizations_count_ptr = nullptr;
 		#endif
 
 		if (for_list)
@@ -649,12 +649,12 @@ Renderer::optimize(Task::List &list) const
 		}
 
 		#ifdef DEBUG_OPTIMIZATION_COUNTERS
-		debug::Log::info("", "optimize category %d index %d: calls %d, changes %d",
+		debug::Log::info({}, "optimize category %d index %d: calls %d, changes %d",
 			current_category_id, current_optimizer_index, (int)calls_count, (int)optimizations_count );
 		#endif
 
 		#ifdef DEBUG_OPTIMIZATION
-		log("", list, etl::strprintf("after optimize category %d index %d", current_category_id, current_optimizer_index));
+		log("", list, strprintf("after optimize category %d index %d", current_category_id, current_optimizer_index));
 		#endif
 
 		if (categories_to_process & depends_from)
@@ -870,13 +870,13 @@ void Renderer::cancel(const Task::List &list)
 
 void
 Renderer::log(
-	const String &logfile,
-	const Task::Handle &task,
+	const filesystem::Path& logfile,
+	const Task::Handle& task,
 	const Optimizer::RunParams* optimization_stack,
 	int level ) const
 {
 	bool use_stack = false;
-	const Optimizer::RunParams* p = optimization_stack ? optimization_stack->get_level(level) : NULL;
+	const Optimizer::RunParams* p = optimization_stack ? optimization_stack->get_level(level) : nullptr;
 	Task::Handle t = task;
 	if (p && p->orig_task == t)
 		{ use_stack = true; t = p->ref_task; }
@@ -892,7 +892,7 @@ Renderer::log(
 			for(Task::Set::const_iterator i = trd.deps.begin(); i != trd.deps.end(); ++i)
 				deps_set.insert((*i)->renderer_data.index);
 			for(std::multiset<int>::const_iterator i = deps_set.begin(); i != deps_set.end(); ++i)
-				deps += etl::strprintf("%d ", *i);
+				deps += strprintf("%d ", *i);
 			deps = "(" + deps.substr(0, deps.size()-1) + ") ";
 		}
 
@@ -903,7 +903,7 @@ Renderer::log(
 			for(Task::Set::const_iterator i = trd.back_deps.begin(); i != trd.back_deps.end(); ++i)
 				back_deps_set.insert((*i)->renderer_data.index);
 			for(std::multiset<int>::const_iterator i = back_deps_set.begin(); i != back_deps_set.end(); ++i)
-				back_deps += etl::strprintf("%d ", *i);
+				back_deps += strprintf("%d ", *i);
 			back_deps = "(" + back_deps.substr(0, back_deps.size()-1) + ") ";
 		}
 
@@ -925,17 +925,17 @@ Renderer::log(
 		debug::Log::info(logfile,
 		      String(level*2, ' ')
 			+ (use_stack ? "*" : "")
-			+ (trd.index ? etl::strprintf("#%05d-%04d ", trd.batch_index, trd.index): "")
+			+ (trd.index ? strprintf("#%05d-%04d ", trd.batch_index, trd.index): "")
 			+ deps
 			+ back_deps
 			+ t->get_token()->name
 			+ ( t->get_bounds().valid()
-			  ? etl::strprintf(" bounds (%f, %f)-(%f, %f)",
+			  ? strprintf(" bounds (%f, %f)-(%f, %f)",
 				t->get_bounds().minx, t->get_bounds().miny,
 				t->get_bounds().maxx, t->get_bounds().maxy )
 			  : "" )
 			+ ( t->target_surface
-              ? etl::strprintf(" source (%f, %f)-(%f, %f) target (%d, %d)-(%d, %d) surface [%s] (%dx%d) id %d",
+              ? strprintf(" source (%f, %f)-(%f, %f) target (%d, %d)-(%d, %d) surface [%s] (%dx%d) id %d",
 				t->source_rect.minx, t->source_rect.miny,
 				t->source_rect.maxx, t->source_rect.maxy,
 				t->target_rect.minx, t->target_rect.miny,
@@ -946,22 +946,22 @@ Renderer::log(
 				t->target_surface->get_id() )
 		      : "" ));
 		for(Task::List::const_iterator i = t->sub_tasks.begin(); i != t->sub_tasks.end(); ++i)
-			log(logfile, *i, use_stack ? optimization_stack : NULL, level+1);
+			log(logfile, *i, use_stack ? optimization_stack : nullptr, level+1);
 	}
 	else
 	{
 		debug::Log::info(logfile,
 			String(level*2, ' ')
 			+ (use_stack ? "*" : "")
-			+ "NULL" );
+			+ "nullptr" );
 	}
 }
 
 void
 Renderer::log(
-	const String &logfile,
-	const Task::List &list,
-	const String &name,
+	const filesystem::Path& logfile,
+	const Task::List& list,
+	const String& name,
 	const Optimizer::RunParams* optimization_stack ) const
 {
 	String line = "-------------------------------------------";
@@ -978,16 +978,16 @@ Renderer::log(
 void
 Renderer::initialize()
 {
-	if (renderers != NULL || queue != NULL)
+	if (renderers || queue)
 		synfig::error("rendering::Renderer already initialized");
 
 	// init debug options
 	if (const char *s = getenv("SYNFIG_RENDERING_DEBUG_TASK_LIST_LOG"))
-		debug_options.task_list_log = s;
+		debug_options.task_list_log = {s};
 	if (const char *s = getenv("SYNFIG_RENDERING_DEBUG_TASK_LIST_OPTIMIZED_LOG"))
-		debug_options.task_list_optimized_log = s;
+		debug_options.task_list_optimized_log = {s};
 	if (const char *s = getenv("SYNFIG_RENDERING_DEBUG_RESULT_IMAGE"))
-		debug_options.result_image = s;
+		debug_options.result_image = {s};
 
 	renderers = new std::map<String, Handle>();
 	queue = new RenderQueue();
@@ -998,7 +998,7 @@ Renderer::initialize()
 void
 Renderer::deinitialize()
 {
-	if (renderers == NULL || queue == NULL)
+	if (!renderers || !queue)
 		synfig::error("rendering::Renderer not initialized");
 
 	while(!get_renderers().empty())
@@ -1007,7 +1007,9 @@ Renderer::deinitialize()
 	deinitialize_renderers();
 
 	delete renderers;
+	renderers = nullptr;
 	delete queue;
+	queue = nullptr;
 }
 
 void
@@ -1038,7 +1040,7 @@ Renderer::get_renderer(const String &name)
 const std::map<String, Renderer::Handle>&
 Renderer::get_renderers()
 {
-	if (renderers == NULL)
+	if (!renderers)
 		synfig::error("rendering::Renderer not initialized");
 	return *renderers;
 }
